@@ -1,17 +1,13 @@
-import dataclasses
 import construct as cs
 import construct_typed as cst
 import typing as t
 import copy
 
 
-@dataclasses.dataclass
-class GuiMetaData:
+class GuiMetaData(t.TypedDict):
     offset_start: int
     offset_end: int
-    length: int
     construct: cs.Construct
-    index: t.Optional[int]
     context: "cs.Context"
 
 
@@ -49,28 +45,29 @@ def get_gui_metadata(obj: t.Any) -> t.Optional[GuiMetaData]:
 
 def add_gui_metadata(obj: t.Any, gui_metadata: GuiMetaData) -> t.Any:
     """ Append the private field "__gui_metadata" to an object """
-    try:
-        obj.__gui_metadata = gui_metadata  # type: ignore
-    except AttributeError:
-        if isinstance(obj, int):
-            obj = IntWithGuiMetadata(obj)
+    obj_type = type(obj)
+    if (obj_type is int) or (obj_type is bool):
+        obj = IntWithGuiMetadata(obj)
+        obj.__gui_metadata = gui_metadata
+    elif obj_type is float:
+        obj = FloatWithGuiMetadata(obj)
+        obj.__gui_metadata = gui_metadata
+    elif obj_type is bytes:
+        obj = BytesWithGuiMetadata(obj)
+        obj.__gui_metadata = gui_metadata
+    elif obj_type is bytearray:
+        obj = BytearrayWithGuiMetadata(obj)
+        obj.__gui_metadata = gui_metadata
+    elif obj_type is str:
+        obj = StrWithGuiMetadata(obj)
+        obj.__gui_metadata = gui_metadata
+    elif obj is None:
+        obj = NoneWithGuiMetadata()
+        obj.__gui_metadata = gui_metadata
+    else:
+        try:
             obj.__gui_metadata = gui_metadata  # type: ignore
-        elif isinstance(obj, float):
-            obj = FloatWithGuiMetadata(obj)
-            obj.__gui_metadata = gui_metadata  # type: ignore
-        elif isinstance(obj, bytes):
-            obj = BytesWithGuiMetadata(obj)
-            obj.__gui_metadata = gui_metadata  # type: ignore
-        elif isinstance(obj, bytearray):
-            obj = BytearrayWithGuiMetadata(obj)
-            obj.__gui_metadata = gui_metadata  # type: ignore
-        elif isinstance(obj, str):
-            obj = StrWithGuiMetadata(obj)
-            obj.__gui_metadata = gui_metadata  # type: ignore
-        elif obj is None:
-            obj = NoneWithGuiMetadata()
-            obj.__gui_metadata = gui_metadata  # type: ignore
-        else:
+        except AttributeError:
             raise ValueError(f"add_gui_metadata dont work with type of {type(obj)}")
     return obj
 
@@ -79,12 +76,6 @@ class IncludeGuiMetaData(cs.Subconstruct):
     """ Include GUI metadata to the parsed object """
 
     def _parse(self, stream, context, path):
-        # Get Index if we are in an Array, Sequence, ...
-        if hasattr(context, "_index"):
-            index = context._index
-        else:
-            index = None
-
         offset_start = cs.stream_tell(stream, path)
         obj = self.subcon._parsereport(stream, context, path)  # type: ignore
         offset_end = cs.stream_tell(stream, path)
@@ -92,9 +83,7 @@ class IncludeGuiMetaData(cs.Subconstruct):
         gui_metadata = GuiMetaData(
             offset_start=offset_start,
             offset_end=offset_end,
-            length=offset_end - offset_start,
             construct=self.subcon,
-            index=index,
             context=context,
         )
 
@@ -182,14 +171,17 @@ def include_metadata(
             cs.Peek,
             cs.NullStripped,
             cs.FixedSized,
-            cst.TStruct,
-            cst.TBitStruct,
         ),
     ):
         constr = copy.copy(constr)  # constr is modified, so we have to make a copy
         constr.subcon = include_metadata(constr.subcon)  # type: ignore
         return constr
 
+    elif isinstance(constr, cst.DataclassStruct):
+        constr = copy.copy(constr)  # constr is modified, so we have to make a copy
+        constr.subcon = include_metadata(constr.subcon)  # type: ignore
+        return IncludeGuiMetaData(constr)
+
     elif isinstance(
         constr,
         (
@@ -210,16 +202,6 @@ def include_metadata(
     ):
         return IncludeGuiMetaData(constr)
 
-    # elif isinstance(
-    #     constr,
-    #     (
-    #         cst.TStruct,
-    #         cst.TBitStruct
-    #     ),
-    # ):
-    #     constr.subcon = include_metadata(constr.subcon)
-    #     return IncludeGuiMetaData(constr)
-
     # TODO:
     # # Grouping:
     # - Sequence
