@@ -11,19 +11,23 @@ from wx.lib.embeddedimage import PyEmbeddedImage
 
 import construct_editor.gallery.example_pe32coff
 import construct_editor.gallery.example_ipstack
+import construct_editor.gallery.test_bytes_greedybytes
 import construct_editor.gallery.test_array
 import construct_editor.gallery.test_greedyrange
 import construct_editor.gallery.test_renamed
 import construct_editor.gallery.test_ifthenelse
 import construct_editor.gallery.test_switch
-import construct_editor.gallery.test_tstruct
-import construct_editor.gallery.test_tbitstruct
+import construct_editor.gallery.test_dataclass_struct
+import construct_editor.gallery.test_dataclass_bit_struct
+import construct_editor.gallery.test_flag
 import construct_editor.gallery.test_enum
 import construct_editor.gallery.test_flagsenum
 import construct_editor.gallery.test_tenum
 import construct_editor.gallery.test_tflagsenum
 import construct_editor.gallery.test_computed
 import construct_editor.gallery.test_timestamp
+import construct_editor.gallery.test_padded
+import construct_editor.gallery.test_aligned
 import construct_editor.gallery.test_pointer_peek_seek_tell
 import construct_editor.gallery.test_pass
 from construct_editor.widgets.construct_hex_editor import ConstructHexEditor
@@ -36,6 +40,7 @@ class ConstructGalleryFrame(wx.Frame):
         self.SetTitle("Construct Gallery")
         self.SetSize(1600, 1000)
         self.SetIcon(icon.GetIcon())
+        self.Center()
 
         self.main_panel = ConstructGallery(self)
 
@@ -53,8 +58,7 @@ class ConstructGallery(wx.Panel):
             "Example: ipstack": construct_editor.gallery.example_ipstack.gallery_item,
             "################ TESTS ####################": None,
             # "## bytes and bits ################": None,
-            # "Test: Bytes (TODO)": None,
-            # "Test: GreedyBytes (TODO)": None,
+            "Test: Bytes/GreedyBytes": construct_editor.gallery.test_bytes_greedybytes.gallery_item,
             # "## integers and floats ###########": None,
             # "Test: FormatField (TODO)": None,
             # "Test: BytesInteger (TODO)": None,
@@ -62,7 +66,7 @@ class ConstructGallery(wx.Panel):
             # "## strings #######################": None,
             # "Test: StringEncoded (TODO)": None,
             "## mappings ######################": None,
-            # "Test: Flag (TODO)": None,
+            "Test: Flag": construct_editor.gallery.test_flag.gallery_item,
             "Test: Enum": construct_editor.gallery.test_enum.gallery_item,
             "Test: FlagsEnum": construct_editor.gallery.test_flagsenum.gallery_item,
             "Test: TEnum": construct_editor.gallery.test_tenum.gallery_item,
@@ -71,8 +75,8 @@ class ConstructGallery(wx.Panel):
             "## structures and sequences ######": None,
             # "Test: Struct (TODO)": None,
             # "Test: Sequence (TODO)": None,
-            "Test: TStruct": construct_editor.gallery.test_tstruct.gallery_item,
-            "Test: TBitStruct": construct_editor.gallery.test_tbitstruct.gallery_item,
+            "Test: DataclassStruct": construct_editor.gallery.test_dataclass_struct.gallery_item,
+            "Test: DataclassBitStruct": construct_editor.gallery.test_dataclass_bit_struct.gallery_item,
             "## arrays ranges and repeaters ######": None,
             "Test: Array": construct_editor.gallery.test_array.gallery_item,
             "Test: GreedyRange": construct_editor.gallery.test_greedyrange.gallery_item,
@@ -100,9 +104,9 @@ class ConstructGallery(wx.Panel):
             "Test: IfThenElse": construct_editor.gallery.test_ifthenelse.gallery_item,
             "Test: Switch": construct_editor.gallery.test_switch.gallery_item,
             # "Test: StopIf (TODO)": None,
-            # "## alignment and padding ##########################": None,
-            # "Test: Padded (TODO)": None,
-            # "Test: Aligned (TODO)": None,
+            "## alignment and padding ##########################": None,
+            "Test: Padded": construct_editor.gallery.test_padded.gallery_item,
+            "Test: Aligned": construct_editor.gallery.test_aligned.gallery_item,
             "## stream manipulation ##########################": None,
             "Test: Pointer/Peek/Seek/Tell": construct_editor.gallery.test_pointer_peek_seek_tell.gallery_item,
             "Test: Pass": construct_editor.gallery.test_pass.gallery_item,
@@ -122,6 +126,17 @@ class ConstructGallery(wx.Panel):
             # "Test: Compressed (TODO)": None,
             # "Test: CompressedLZ4 (TODO)": None,
             # "Test: Rebuffered (TODO)": None,
+            # "## lazy equivalents ##########################": None,
+            # "Test: Lazy (TODO)": None,
+            # "Test: LazyStruct (TODO)": None,
+            # "Test: LazyArray (TODO)": None,
+            # "Test: LazyBound (TODO)": None,
+            # "## adapters and validators ##########################": None,
+            # "Test: ExprAdapter (TODO)": None,
+            # "Test: ExprSymmetricAdapter (TODO)": None,
+            # "Test: ExprValidator (TODO)": None,
+            # "Test: Slicing (TODO)": None,
+            # "Test: Indexing (TODO)": None,
         }
         self.gallery_selection = 1
         default_gallery = list(self.construct_gallery.keys())[self.gallery_selection]
@@ -248,17 +263,15 @@ class ConstructGallery(wx.Panel):
             example_binary = bytes(0)
 
         self.Freeze()
-        self.construct_hex_editor.binary = example_binary
         self.construct_hex_editor.construct = gallery_item.construct
         self.construct_hex_editor.contextkw = gallery_item.contextkw
-        self.construct_hex_editor.refresh()
+        self.construct_hex_editor.binary = example_binary
         self.construct_hex_editor.construct_editor.expand_all()
         self.Thaw()
 
     def on_clear_binary_clicked(self, event):
         self.example_selector_lbx.SetSelection(wx.NOT_FOUND)
         self.construct_hex_editor.binary = bytes()
-        self.construct_hex_editor.refresh()
 
     def on_example_selection_changed(self, event):
         selection = self.gallery_selector_lbx.GetStringSelection()
@@ -267,7 +280,6 @@ class ConstructGallery(wx.Panel):
 
         # Set example binary
         self.construct_hex_editor.binary = example_binary
-        self.construct_hex_editor.refresh()
 
     def on_load_binary_file_clicked(self, event):
         with wx.FileDialog(
@@ -354,6 +366,7 @@ def main():
     inspect = False
     if inspect is True:
         import wx.lib.mixins.inspection as wit
+
         app = wit.InspectableApp()
     else:
         app = wx.App(False)
