@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 import enum
-from typing import Any, Callable, Dict, List, Optional, Type, Union
+from typing import Any, Callable, Dict, List, Optional
 
 import construct as cs
-import construct_typed as cst
 import wx
 import wx.dataview as dv
-import dataclasses
 from construct_editor.helper import CallbackList
+import textwrap
 
 from construct_editor.helper.preprocessor import include_metadata
 from construct_editor.helper.wrapper import (
@@ -134,14 +133,6 @@ class ContextMenu(wx.Menu):
 
         self.AppendSeparator()
 
-        item: wx.MenuItem = self.Append(wx.ID_ANY, "Expand All\tCtrl+E")
-        self.Bind(wx.EVT_MENU, self.on_expand_all, id=item.Id)
-
-        item: wx.MenuItem = self.Append(wx.ID_ANY, "Collapse All\tCtrl+W")
-        self.Bind(wx.EVT_MENU, self.on_collapse_all, id=item.Id)
-
-        self.AppendSeparator()
-
         item: wx.MenuItem = self.AppendCheckItem(wx.ID_ANY, "Hide Protected")
         self.Bind(wx.EVT_MENU, self.on_hide_protected, id=item.Id)
         item.Check(self.parent.hide_protected)
@@ -181,12 +172,6 @@ class ContextMenu(wx.Menu):
         if entry is not None:
             entry.modify_context_menu(self)
 
-    def on_expand_all(self, event):
-        self.parent.expand_all()
-
-    def on_collapse_all(self, event):
-        self.parent.collapse_all()
-
     def on_hide_protected(self, event):
         checked = self.hide_protected_mi.IsChecked()
         self.parent.hide_protected = checked
@@ -252,7 +237,7 @@ class ConstructEditorModel(dv.PyDataViewModel):
         # so any Python object can be used as data nodes. If the data nodes
         # are weak-referencable then the objmapper can use a
         # WeakValueDictionary instead.
-        self.UseWeakRefs(True)
+        # self.UseWeakRefs(True)  # weak refs are slower when creating a large number of items
 
         self.command_processor = wx.CommandProcessor()
 
@@ -298,22 +283,25 @@ class ConstructEditorModel(dv.PyDataViewModel):
 
         if not parent:
             entry = self.root_entry
-            item = self.ObjectToItem(entry)
-            entry.dvc_item = item
-            children.append(item)
+            if entry.dvc_item is None:
+                item = self.ObjectToItem(entry)
+                entry.dvc_item = item
+            children.append(entry.dvc_item)
             return 1
 
         parent_entry = self.ItemToObject(parent)
         if not isinstance(parent_entry, EntryConstruct):
             raise ValueError(f"{repr(parent_entry)} is no valid entry")
 
-        for entry in parent_entry.subentries:
-            name = entry.name
-            if (self.hide_protected == True) and (name.startswith("_") or name == ""):
-                continue
-            item = self.ObjectToItem(entry)
-            entry.dvc_item = item
-            children.append(item)
+        if parent_entry.subentries is not None:
+            for entry in parent_entry.subentries:
+                name = entry.name
+                if (self.hide_protected == True) and (name.startswith("_") or name == ""):
+                    continue
+                if entry.dvc_item is None:
+                    item = self.ObjectToItem(entry)
+                    entry.dvc_item = item
+                children.append(entry.dvc_item)
         return len(children)
 
     def IsContainer(self, item):
@@ -515,7 +503,8 @@ class ConstructEditor(wx.Panel):
             self._clear_status_bar()
 
             # expand everything
-            self._model.root_entry.dvc_item_restore_expansion()
+            if self._model.root_entry is not None:
+                self._model.root_entry.dvc_item_restore_expansion()
 
             # restore selection
             self._dvc.SetSelections(selections)
@@ -551,8 +540,7 @@ class ConstructEditor(wx.Panel):
             raise e
 
         # parse the build binary, so that constructs that parses from nothing are shown correctly (eg. cs.Peek)
-        # TODO: If this is uncommented, the focus of the ObjPanel is lost every time a change is made
-        # wx.CallAfter(lambda: self.parse(binary, **contextkw))
+        wx.CallAfter(lambda: self.parse(binary, **contextkw))
 
         return binary
 
@@ -564,12 +552,16 @@ class ConstructEditor(wx.Panel):
 
     @construct.setter
     def construct(self, val: cs.Construct):
+        # add root name, is none is available
+        if val.name is None:
+            val = "root" / val
+
         # modify the copied construct, so that each item also includes metadata for the GUI
         self._construct = include_metadata(val)
 
         # create entry from the construct
         self._model.root_entry = create_entry_from_construct(
-            self._model, None, cs.Renamed(self._construct, newname="root")
+            self._model, None, self._construct, None, ""
         )
 
         self._model.list_viewed_entries.clear()
@@ -593,21 +585,21 @@ class ConstructEditor(wx.Panel):
         self._model.hide_protected = value
         self.reload()
 
+    # expand_children #########################################################
+    def expand_children(self, entry: EntryConstruct):
+        if entry.subentries is not None:
+            if entry.dvc_item is not None:
+                self._dvc.Expand(entry.dvc_item)
+            for sub_entry in entry.subentries:
+                self.expand_children(sub_entry)
+
     # expand_all ##############################################################
     def expand_all(self):
         """
         Expand all Entries
         """
-
-        def dvc_expand(entry: EntryConstruct):
-            if entry.subentries is not None:
-                if entry.dvc_item is not None:
-                    self._dvc.Expand(entry.dvc_item)
-                for sub_entry in entry.subentries:
-                    dvc_expand(sub_entry)
-
         if self._model.root_entry:
-            dvc_expand(self._model.root_entry)
+            self.expand_children(self._model.root_entry)
 
     # expand_level ############################################################
     def expand_level(self, level: int):
@@ -628,23 +620,23 @@ class ConstructEditor(wx.Panel):
         if self._model.root_entry:
             dvc_expand(self._model.root_entry, 1)
 
+    # collapse_all ############################################################
+    def collapse_children(self, entry: EntryConstruct):
+        subentries = entry.subentries
+        dvc_item = entry.dvc_item
+        if subentries is not None:
+            for sub_entry in subentries:
+                self.collapse_children(sub_entry)
+            if dvc_item is not None:
+                self._dvc.Collapse(dvc_item)
+
     # collapse_all ############################################################
     def collapse_all(self):
         """
         Collapse all Entries
         """
-
-        def dvc_collapse(entry: EntryConstruct):
-            subentries = entry.subentries
-            dvc_item = entry.dvc_item
-            if subentries is not None:
-                for sub_entry in subentries:
-                    dvc_collapse(sub_entry)
-                if dvc_item is not None:
-                    self._dvc.Collapse(dvc_item)
-
         if self._model.root_entry:
-            dvc_collapse(self._model.root_entry)
+            self.collapse_children(self._model.root_entry)
 
         # expand the root entry again
         self.expand_level(1)
@@ -667,10 +659,11 @@ class ConstructEditor(wx.Panel):
 
         list_cols = 0
         for list_viewed_entry in self._model.list_viewed_entries:
-            for subentry in list_viewed_entry.subentries:
-                flat_list = []
-                subentry.create_flat_subentry_list(flat_list)
-                list_cols = max(list_cols, len(flat_list))
+            if list_viewed_entry.subentries is not None:
+                for subentry in list_viewed_entry.subentries:
+                    flat_list = []
+                    subentry.create_flat_subentry_list(flat_list)
+                    list_cols = max(list_cols, len(flat_list))
 
         for list_col in range(list_cols):
             self._dvc.AppendTextColumn(
@@ -721,8 +714,8 @@ class ConstructEditor(wx.Panel):
         bytes_info = ""
         metadata = entry.obj_metadata
         if metadata is not None:
-            start = metadata.offset_start
-            end = metadata.offset_end - 1
+            start = metadata["offset_start"]
+            end = metadata["offset_end"] - 1
             size = end - start + 1
             if size > 0:
                 bytes_info = f"Bytes: {start}-{end} ({size})"
@@ -734,7 +727,8 @@ class ConstructEditor(wx.Panel):
 
     def _on_dvc_value_changed(self, event: dv.DataViewEvent):
         """ This method is called, if a value in the dvc has changed. """
-        self.on_root_obj_changed.fire(self._model.root_obj)
+        if event.Column == ConstructEditorColumn.Value:
+            self.on_root_obj_changed.fire(self._model.root_obj)
 
     def _on_dvc_motion(self, event: wx.MouseEvent):
         # this is a mouse event, so we have to calculate the position of
@@ -750,7 +744,7 @@ class ConstructEditor(wx.Panel):
         if col.ModelColumn == ConstructEditorColumn.Name:
             # only set tooltip if the obj changed. this prevents flickering
             if self._last_motion_obj is not obj:
-                self._dvc_main_window.SetToolTip(obj.docs)
+                self._dvc_main_window.SetToolTip(textwrap.dedent(obj.docs).strip())
             self._last_motion_obj = obj
         else:
             self._dvc_main_window.SetToolTip("")
