@@ -150,9 +150,9 @@ class ConstructHexEditor(wx.Panel):
     def _on_entry_selected(self, entry: EntryConstruct):
         metadata = entry.obj_metadata
         if metadata is not None:
-            self.hex_editor.colorise(metadata.offset_start, metadata.offset_end, refresh=False)
-            self.hex_editor.scroll_to_idx(metadata.offset_end - 1, refresh=False)
-            self.hex_editor.scroll_to_idx(metadata.offset_start, refresh=False)
+            self.hex_editor.colorise(metadata["offset_start"], metadata["offset_end"], refresh=False)
+            self.hex_editor.scroll_to_idx(metadata["offset_end"] - 1, refresh=False)
+            self.hex_editor.scroll_to_idx(metadata["offset_start"], refresh=False)
             self.hex_editor.refresh()
         else:
             self.hex_editor.colorise(0, 0)
